@@ -32,6 +32,7 @@
 #include <nm-connection.h>
 #include <nm-client.h>
 #include <nm-remote-settings.h>
+#include "nm-connection-editor.h"
 #include "utils.h"
 
 /* for ARPHRD_ETHER / ARPHRD_INFINIBAND for MAC utilies */
@@ -65,6 +66,7 @@ typedef struct {
 	GObject parent;
 
 	gboolean initialized;
+	gboolean inter_page_change_running;
 	GtkBuilder *builder;
 	GtkWidget *page;
 	char *title;
@@ -72,6 +74,7 @@ typedef struct {
 	DBusGProxy *proxy;
 	gulong secrets_done_validate;
 
+	NMConnectionEditor *editor;
 	NMConnection *connection;
 	GtkWindow *parent_window;
 	NMClient *client;
@@ -82,8 +85,9 @@ typedef struct {
 	GObjectClass parent;
 
 	/* Virtual functions */
-	gboolean    (*validate)     (CEPage *self, NMConnection *connection, GError **error);
+	gboolean    (*ce_page_validate_v) (CEPage *self, NMConnection *connection, GError **error);
 	gboolean    (*last_update)  (CEPage *self, NMConnection *connection, GError **error);
+	gboolean    (*inter_page_change)  (CEPage *self);
 
 	/* Signals */
 	void        (*changed)     (CEPage *self);
@@ -91,7 +95,8 @@ typedef struct {
 } CEPageClass;
 
 
-typedef CEPage* (*CEPageNewFunc)(NMConnection *connection,
+typedef CEPage* (*CEPageNewFunc)(NMConnectionEditor *editor,
+                                 NMConnection *connection,
                                  GtkWindow *parent,
                                  NMClient *client,
                                  NMRemoteSettings *settings,
@@ -107,6 +112,7 @@ const char * ce_page_get_title (CEPage *self);
 
 gboolean ce_page_validate (CEPage *self, NMConnection *connection, GError **error);
 gboolean ce_page_last_update (CEPage *self, NMConnection *connection, GError **error);
+gboolean ce_page_inter_page_change (CEPage *self);
 
 void ce_page_setup_mac_combo (CEPage *self, GtkComboBox *combo,
                               const GByteArray *mac, int type, char **mac_list);
@@ -120,9 +126,12 @@ void ce_page_setup_device_combo (CEPage *self,
                                  int mac_type,
                                  const char *mac_property,
                                  gboolean ifname_first);
-gboolean ce_page_mac_entry_valid (GtkEntry *entry, int type);
+gboolean ce_page_mac_entry_valid (GtkEntry *entry, int type, const char *property_name, GError **error);
+gboolean ce_page_interface_name_valid (const char *iface, const char *property_name, GError **error);
 gboolean ce_page_device_entry_get (GtkEntry *entry, int type,
-                                   char **ifname, GByteArray **mac);
+                                   char **ifname, GByteArray **mac,
+                                   const char *device_name,
+                                   GError **error);
 void ce_page_mac_to_entry (const GByteArray *mac, int type, GtkEntry *entry);
 GByteArray *ce_page_entry_to_mac (GtkEntry *entry, int type, gboolean *invalid);
 
@@ -151,6 +160,7 @@ NMConnection *ce_page_new_connection (const char *format,
                                       gpointer user_data);
 
 CEPage *ce_page_new (GType page_type,
+                     NMConnectionEditor *editor,
                      NMConnection *connection,
                      GtkWindow *parent_window,
                      NMClient *client,
@@ -159,5 +169,6 @@ CEPage *ce_page_new (GType page_type,
                      const char *widget_name,
                      const char *title);
 
+
 #endif  /* __CE_PAGE_H__ */
 
