@@ -141,7 +141,7 @@ static gboolean
 idle_create_connection (gpointer user_data)
 {
 	NMConnectionList *list = user_data;
-	GType ctype = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (list), "nm-connection-editor-ctype"));
+	GType ctype = (GType) GPOINTER_TO_SIZE (g_object_get_data (G_OBJECT (list), "nm-connection-editor-ctype"));
 	char *detail = g_object_get_data (G_OBJECT (list), "nm-connection-editor-detail");
 
 	nm_connection_list_create (list, ctype, detail);
@@ -193,7 +193,7 @@ handle_arguments (NMConnectionList *list,
 		 */
 		g_idle_add (idle_create_connection, list);
 		g_object_set_data (G_OBJECT (list), "nm-connection-editor-ctype",
-		                   GUINT_TO_POINTER (ctype));
+		                   GSIZE_TO_POINTER (ctype));
 		g_object_set_data_full (G_OBJECT (list), "nm-connection-editor-detail",
 		                        g_strdup (detail), g_free);
 
