@@ -45,7 +45,8 @@ typedef struct {
 
 GType ce_page_bridge_get_type (void);
 
-CEPage *ce_page_bridge_new (NMConnection *connection,
+CEPage *ce_page_bridge_new (NMConnectionEditor *editor,
+                            NMConnection *connection,
                             GtkWindow *parent,
                             NMClient *client,
                             NMRemoteSettings *settings,
