@@ -138,7 +138,8 @@ finish_setup (CEPageInfiniband *self, gpointer unused, GError *error, gpointer u
 }
 
 CEPage *
-ce_page_infiniband_new (NMConnection *connection,
+ce_page_infiniband_new (NMConnectionEditor *editor,
+                        NMConnection *connection,
                         GtkWindow *parent_window,
                         NMClient *client,
                         NMRemoteSettings *settings,
@@ -149,6 +150,7 @@ ce_page_infiniband_new (NMConnection *connection,
 	CEPageInfinibandPrivate *priv;
 
 	self = CE_PAGE_INFINIBAND (ce_page_new (CE_TYPE_PAGE_INFINIBAND,
+	                                        editor,
 	                                        connection,
 	                                        parent_window,
 	                                        client,
@@ -197,7 +199,7 @@ ui_to_setting (CEPageInfiniband *self)
 
 	entry = gtk_bin_get_child (GTK_BIN (priv->device_combo));
 	if (entry)
-		ce_page_device_entry_get (GTK_ENTRY (entry), ARPHRD_INFINIBAND, &ifname, &device_mac);
+		ce_page_device_entry_get (GTK_ENTRY (entry), ARPHRD_INFINIBAND, &ifname, &device_mac, NULL, NULL);
 
 	g_object_set (s_con,
 	              NM_SETTING_CONNECTION_INTERFACE_NAME, ifname,
@@ -214,7 +216,7 @@ ui_to_setting (CEPageInfiniband *self)
 }
 
 static gboolean
-validate (CEPage *page, NMConnection *connection, GError **error)
+ce_page_validate_v (CEPage *page, NMConnection *connection, GError **error)
 {
 	CEPageInfiniband *self = CE_PAGE_INFINIBAND (page);
 	CEPageInfinibandPrivate *priv = CE_PAGE_INFINIBAND_GET_PRIVATE (self);
@@ -222,7 +224,7 @@ validate (CEPage *page, NMConnection *connection, GError **error)
 
 	entry = gtk_bin_get_child (GTK_BIN (priv->device_combo));
 	if (entry) {
-		if (!ce_page_device_entry_get (GTK_ENTRY (entry), ARPHRD_INFINIBAND, NULL, NULL))
+		if (!ce_page_device_entry_get (GTK_ENTRY (entry), ARPHRD_INFINIBAND, NULL, NULL, _("infiniband device"), error))
 			return FALSE;
 	}
 
@@ -244,7 +246,7 @@ ce_page_infiniband_class_init (CEPageInfinibandClass *infiniband_class)
 	g_type_class_add_private (object_class, sizeof (CEPageInfinibandPrivate));
 
 	/* virtual methods */
-	parent_class->validate = validate;
+	parent_class->ce_page_validate_v = ce_page_validate_v;
 }
 
 
