@@ -64,6 +64,8 @@ typedef struct {
 
 	GtkComboBox *method;
 	GtkListStore *method_store;
+	int normal_method_idx;
+	int hotspot_method_idx;
 
 	/* Addresses */
 	GtkWidget *addr_label;
@@ -104,6 +106,7 @@ typedef struct {
 
 #define METHOD_COL_NAME 0
 #define METHOD_COL_NUM  1
+#define METHOD_COL_ENABLED 2
 
 #define IP4_METHOD_AUTO            0
 #define IP4_METHOD_AUTO_ADDRESSES  1
@@ -121,6 +124,7 @@ ip4_private_init (CEPageIP4 *self, NMConnection *connection)
 	NMSettingConnection *s_con;
 	const char *connection_type;
 	char *str_auto = NULL, *str_auto_only = NULL;
+	GList *cells;
 
 	builder = CE_PAGE (self)->builder;
 
@@ -147,19 +151,24 @@ ip4_private_init (CEPageIP4 *self, NMConnection *connection)
 	}
 
 	priv->method = GTK_COMBO_BOX (gtk_builder_get_object (builder, "ip4_method"));
+	cells = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (priv->method));
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (priv->method), cells->data,
+	                               "sensitive", METHOD_COL_ENABLED);
 
-	priv->method_store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_UINT);
+	priv->method_store = gtk_list_store_new (3, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_BOOLEAN);
 
 	gtk_list_store_append (priv->method_store, &iter);
 	gtk_list_store_set (priv->method_store, &iter,
 	                    METHOD_COL_NAME, str_auto,
 	                    METHOD_COL_NUM, IP4_METHOD_AUTO,
+	                    METHOD_COL_ENABLED, TRUE,
 	                    -1);
 
 	gtk_list_store_append (priv->method_store, &iter);
 	gtk_list_store_set (priv->method_store, &iter,
 	                    METHOD_COL_NAME, str_auto_only,
 	                    METHOD_COL_NUM, IP4_METHOD_AUTO_ADDRESSES,
+	                    METHOD_COL_ENABLED, TRUE,
 	                    -1);
 
 	/* Manual is pointless for Mobile Broadband */
@@ -170,6 +179,7 @@ ip4_private_init (CEPageIP4 *self, NMConnection *connection)
 		gtk_list_store_set (priv->method_store, &iter,
 		                    METHOD_COL_NAME, _("Manual"),
 		                    METHOD_COL_NUM, IP4_METHOD_MANUAL,
+		                    METHOD_COL_ENABLED, TRUE,
 		                    -1);
 	}
 
@@ -182,12 +192,14 @@ ip4_private_init (CEPageIP4 *self, NMConnection *connection)
 		gtk_list_store_set (priv->method_store, &iter,
 		                    METHOD_COL_NAME, _("Link-Local Only"),
 		                    METHOD_COL_NUM, IP4_METHOD_LINK_LOCAL,
+		                    METHOD_COL_ENABLED, TRUE,
 		                    -1);
 
 		gtk_list_store_append (priv->method_store, &iter);
 		gtk_list_store_set (priv->method_store, &iter,
 		                    METHOD_COL_NAME, _("Shared to other computers"),
 		                    METHOD_COL_NUM, IP4_METHOD_SHARED,
+		                    METHOD_COL_ENABLED, TRUE,
 		                    -1);
 	}
 
@@ -197,6 +209,7 @@ ip4_private_init (CEPageIP4 *self, NMConnection *connection)
 		gtk_list_store_set (priv->method_store, &iter,
 		                    METHOD_COL_NAME, _("Disabled"),
 		                    METHOD_COL_NUM, IP4_METHOD_DISABLED,
+		                    METHOD_COL_ENABLED, TRUE,
 		                    -1);
 	}
 	gtk_combo_box_set_model (priv->method, GTK_TREE_MODEL (priv->method_store));
@@ -988,7 +1001,8 @@ finish_setup (CEPageIP4 *self, gpointer unused, GError *error, gpointer user_dat
 }
 
 CEPage *
-ce_page_ip4_new (NMConnection *connection,
+ce_page_ip4_new (NMConnectionEditor *editor,
+                 NMConnection *connection,
                  GtkWindow *parent_window,
                  NMClient *client,
                  NMRemoteSettings *settings,
@@ -1000,6 +1014,7 @@ ce_page_ip4_new (NMConnection *connection,
 	NMSettingConnection *s_con;
 
 	self = CE_PAGE_IP4 (ce_page_new (CE_TYPE_PAGE_IP4,
+	                                 editor,
 	                                 connection,
 	                                 parent_window,
 	                                 client,
@@ -1039,7 +1054,7 @@ free_one_addr (gpointer data)
 }
 
 static gboolean
-ui_to_setting (CEPageIP4 *self)
+ui_to_setting (CEPageIP4 *self, GError **error)
 {
 	CEPageIP4Private *priv = CE_PAGE_IP4_GET_PRIVATE (self);
 	GtkTreeModel *model;
@@ -1096,8 +1111,7 @@ ui_to_setting (CEPageIP4 *self)
 
 		gtk_tree_model_get (model, &tree_iter, COL_ADDRESS, &item, -1);
 		if (!item || inet_pton (AF_INET, item, &tmp_addr) <= 0) {
-			g_warning ("%s: IPv4 address '%s' missing or invalid!",
-			           __func__, item ? item : "<none>");
+			g_set_error (error, NMA_ERROR, NMA_ERROR_GENERIC, _("IPv4 address \"%s\" invalid"), item ? item : "");
 			g_free (item);
 			goto out;
 		}
@@ -1105,14 +1119,12 @@ ui_to_setting (CEPageIP4 *self)
 
 		gtk_tree_model_get (model, &tree_iter, COL_PREFIX, &item, -1);
 		if (!item) {
-			g_warning ("%s: IPv4 prefix '%s' missing!",
-			           __func__, item ? item : "<none>");
+			g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("IPv4 address netmask missing"));
 			goto out;
 		}
 
 		if (!parse_netmask (item, &prefix)) {
-			g_warning ("%s: IPv4 prefix '%s' invalid!",
-			           __func__, item ? item : "<none>");
+			g_set_error (error, NMA_ERROR, NMA_ERROR_GENERIC, _("IPv4 address netmask \"%s\" invalid"), item);
 			g_free (item);
 			goto out;
 		}
@@ -1121,8 +1133,7 @@ ui_to_setting (CEPageIP4 *self)
 		/* Gateway is optional... */
 		gtk_tree_model_get (model, &tree_iter, COL_GATEWAY, &item, -1);
 		if (item && strlen (item) && inet_pton (AF_INET, item, &tmp_gateway) <= 0) {
-			g_warning ("%s: IPv4 gateway '%s' invalid!",
-			           __func__, item ? item : "<none>");
+			g_set_error (error, NMA_ERROR, NMA_ERROR_GENERIC, _("IPv4 gateway \"%s\" invalid"), item);
 			g_free (item);
 			goto out;
 		}
@@ -1162,6 +1173,7 @@ ui_to_setting (CEPageIP4 *self)
 			if (inet_pton (AF_INET, stripped, &tmp_addr))
 				g_array_append_val (dns_servers, tmp_addr.s_addr);
 			else {
+				g_set_error (error, NMA_ERROR, NMA_ERROR_GENERIC, _("IPv4 DNS server \"%s\" invalid"), stripped);
 				g_strfreev (items);
 				goto out;
 			}
@@ -1221,22 +1233,113 @@ out:
 }
 
 static gboolean
-validate (CEPage *page, NMConnection *connection, GError **error)
+ce_page_validate_v (CEPage *page, NMConnection *connection, GError **error)
 {
 	CEPageIP4 *self = CE_PAGE_IP4 (page);
 	CEPageIP4Private *priv = CE_PAGE_IP4_GET_PRIVATE (self);
 
-	if (!ui_to_setting (self))
+	if (!ui_to_setting (self, error))
 		return FALSE;
 	return nm_setting_verify (NM_SETTING (priv->setting), NULL, error);
 }
 
+static gboolean
+get_iter_for_method (GtkTreeModel *model, int column, GtkTreeIter *iter)
+{
+	int col;
+
+	if (gtk_tree_model_get_iter_first (model, iter)) {
+		do {
+			gtk_tree_model_get (model, iter, METHOD_COL_NUM, &col, -1);
+			if (col == column)
+				return TRUE;
+		} while (gtk_tree_model_iter_next (model, iter));
+	}
+	return FALSE;
+}
+
+static void
+toggle_method_sensitivity (CEPage *page, int column, gboolean sensitive)
+{
+	CEPageIP4 *self = CE_PAGE_IP4 (page);
+	CEPageIP4Private *priv = CE_PAGE_IP4_GET_PRIVATE (self);
+	GtkTreeModel *model = GTK_TREE_MODEL (priv->method_store);
+	GtkTreeIter iter;
+
+	if (get_iter_for_method (model, column, &iter))
+		gtk_list_store_set (priv->method_store, &iter, METHOD_COL_ENABLED, sensitive, -1);
+}
+
+static gboolean
+get_method_sensitivity (CEPage *page, int column)
+{
+	CEPageIP4 *self = CE_PAGE_IP4 (page);
+	CEPageIP4Private *priv = CE_PAGE_IP4_GET_PRIVATE (self);
+	GtkTreeModel *model = GTK_TREE_MODEL (priv->method_store);
+	GtkTreeIter iter;
+	gboolean sensitive = FALSE;
+
+	if (get_iter_for_method (model, column, &iter))
+		gtk_tree_model_get (GTK_TREE_MODEL (priv->method_store), &iter, METHOD_COL_ENABLED, &sensitive, -1);
+	return sensitive;
+}
+
+static void
+change_method_combo (CEPage *page, gboolean is_hotspot)
+{
+	CEPageIP4 *self = CE_PAGE_IP4 (page);
+	CEPageIP4Private *priv = CE_PAGE_IP4_GET_PRIVATE (self);
+
+	/* Store previous active method */
+	if (get_method_sensitivity (page, IP4_METHOD_AUTO))
+		priv->normal_method_idx = gtk_combo_box_get_active (priv->method);
+	else
+		priv->hotspot_method_idx = gtk_combo_box_get_active (priv->method);
+
+	/* Set active method */
+	if (is_hotspot) {
+		if (priv->hotspot_method_idx == -1) {
+			int method = IP4_METHOD_SHARED;
+			if (g_strcmp0 (nm_setting_ip4_config_get_method (priv->setting),
+			               NM_SETTING_IP4_CONFIG_METHOD_DISABLED) == 0)
+				method = IP4_METHOD_DISABLED;
+			gtk_combo_box_set_active (priv->method, method);
+		} else
+			gtk_combo_box_set_active (priv->method, priv->hotspot_method_idx);
+	} else {
+		if (priv->normal_method_idx != -1)
+			gtk_combo_box_set_active (priv->method, priv->normal_method_idx);
+	}
+
+	toggle_method_sensitivity (page, IP4_METHOD_AUTO, !is_hotspot);
+	toggle_method_sensitivity (page, IP4_METHOD_AUTO_ADDRESSES, !is_hotspot);
+	toggle_method_sensitivity (page, IP4_METHOD_MANUAL, !is_hotspot);
+	toggle_method_sensitivity (page, IP4_METHOD_LINK_LOCAL, !is_hotspot);
+}
+
+static gboolean
+inter_page_change (CEPage *page)
+{
+	gpointer wifi_mode_ap;
+
+	if (nm_connection_editor_inter_page_get_value (page->editor, INTER_PAGE_CHANGE_WIFI_MODE, &wifi_mode_ap)) {
+		/* For Wi-Fi AP mode restrict IPv4 methods to shared and disabled */
+		if (GPOINTER_TO_UINT (wifi_mode_ap))
+			change_method_combo (page, TRUE);
+		else
+			change_method_combo (page, FALSE);
+	}
+	return TRUE;
+}
+
 static void
 ce_page_ip4_init (CEPageIP4 *self)
 {
 	CEPageIP4Private *priv = CE_PAGE_IP4_GET_PRIVATE (self);
 
 	priv->last_column = -1;
+	priv->normal_method_idx = -1;
+	priv->hotspot_method_idx = -1;
 }
 
 static void
@@ -1266,6 +1369,7 @@ ce_page_ip4_class_init (CEPageIP4Class *ip4_class)
 	g_type_class_add_private (object_class, sizeof (CEPageIP4Private));
 
 	/* virtual methods */
-	parent_class->validate = validate;
+	parent_class->ce_page_validate_v = ce_page_validate_v;
+	parent_class->inter_page_change = inter_page_change;
 	object_class->dispose = dispose;
 }
