@@ -298,7 +298,8 @@ finish_setup (CEPageMobile *self, gpointer unused, GError *error, gpointer user_
 }
 
 CEPage *
-ce_page_mobile_new (NMConnection *connection,
+ce_page_mobile_new (NMConnectionEditor *editor,
+                    NMConnection *connection,
                     GtkWindow *parent_window,
                     NMClient *client,
                     NMRemoteSettings *settings,
@@ -309,6 +310,7 @@ ce_page_mobile_new (NMConnection *connection,
 	CEPageMobilePrivate *priv;
 
 	self = CE_PAGE_MOBILE (ce_page_new (CE_TYPE_PAGE_MOBILE,
+	                                    editor,
 	                                    connection,
 	                                    parent_window,
 	                                    client,
@@ -401,7 +403,7 @@ ui_to_setting (CEPageMobile *self)
 }
 
 static gboolean
-validate (CEPage *page, NMConnection *connection, GError **error)
+ce_page_validate_v (CEPage *page, NMConnection *connection, GError **error)
 {
 	CEPageMobile *self = CE_PAGE_MOBILE (page);
 	CEPageMobilePrivate *priv = CE_PAGE_MOBILE_GET_PRIVATE (self);
@@ -432,7 +434,7 @@ ce_page_mobile_class_init (CEPageMobileClass *mobile_class)
 	g_type_class_add_private (object_class, sizeof (CEPageMobilePrivate));
 
 	/* virtual methods */
-	parent_class->validate = validate;
+	parent_class->ce_page_validate_v = ce_page_validate_v;
 	object_class->dispose = dispose;
 }
 
