@@ -36,6 +36,7 @@
 
 #include "wireless-security.h"
 #include "eap-method.h"
+#include "utils.h"
 
 G_DEFINE_BOXED_TYPE (WirelessSecurity, wireless_security, wireless_security_ref, wireless_security_unref)
 
@@ -68,12 +69,18 @@ wireless_security_changed_cb (GtkWidget *ignored, gpointer user_data)
 }
 
 gboolean
-wireless_security_validate (WirelessSecurity *sec, const GByteArray *ssid)
+wireless_security_validate (WirelessSecurity *sec, GError **error)
 {
+	gboolean result;
+
 	g_return_val_if_fail (sec != NULL, FALSE);
+	g_return_val_if_fail (!error || !*error, FALSE);
 
 	g_assert (sec->validate);
-	return (*(sec->validate)) (sec, ssid);
+	result = (*(sec->validate)) (sec, error);
+	if (!result && error && !error)
+		g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("Unknown error validating 802.1x security"));
+	return result;
 }
 
 void
@@ -192,6 +199,7 @@ wireless_security_init (gsize obj_size,
 
 	sec->destroy = destroy;
 	sec->adhoc_compatible = TRUE;
+	sec->hotspot_compatible = TRUE;
 
 	return sec;
 }
@@ -204,6 +212,14 @@ wireless_security_adhoc_compatible (WirelessSecurity *sec)
 	return sec->adhoc_compatible;
 }
 
+gboolean
+wireless_security_hotspot_compatible (WirelessSecurity *sec)
+{
+	g_return_val_if_fail (sec != NULL, FALSE);
+
+	return sec->hotspot_compatible;
+}
+
 void
 wireless_security_set_userpass (WirelessSecurity *sec,
                                 const char *user,
@@ -293,7 +309,7 @@ ws_802_1x_add_to_size_group (WirelessSecurity *sec,
 }
 
 gboolean
-ws_802_1x_validate (WirelessSecurity *sec, const char *combo_name)
+ws_802_1x_validate (WirelessSecurity *sec, const char *combo_name, GError **error)
 {
 	GtkWidget *widget;
 	GtkTreeModel *model;
@@ -308,7 +324,7 @@ ws_802_1x_validate (WirelessSecurity *sec, const char *combo_name)
 	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter);
 	gtk_tree_model_get (model, &iter, AUTH_METHOD_COLUMN, &eap, -1);
 	g_assert (eap);
-	valid = eap_method_validate (eap);
+	valid = eap_method_validate (eap, error);
 	eap_method_unref (eap);
 	return valid;
 }
